# coding: utf-8
from models import Film
from django.shortcuts import render_to_response
from django.template import RequestContext

def film_list(request, prefix=None):
    search = request.GET.get('search')

    if prefix is not None:
        films = Film.objects.filter(name_czech__istartswith=prefix)
    elif search is not None:
        films = Film.objects.filter(name_czech__icontains=search)
    else:
        films = None

    letters = [chr(c) for c in range(ord('A'), ord('Z') + 1)]

    return render_to_response('film_list.html', locals(), context_instance=RequestContext(request))

from forms import ImageForm
from models import FORMAT_CHOICES, FilmImage
from django.http import HttpResponseRedirect 

def film_detail(request, film_id):
    try:
        film = Film.objects.filter(id=film_id)[0]
    except IndexError:
        return HttpResponseRedirect('/nabidka/')

    film.format = FORMAT_CHOICES[film.format][1]

    if request.method == 'POST' and request.user.is_authenticated():
        form = ImageForm(request.POST, request.FILES)
        
        if form.is_valid():
            film_image = FilmImage(film=film)

            if request.FILES.has_key('image'):
                file = request.FILES['image']
                film_image.image.save(file.name, file)
    else:
        form = ImageForm()

    images = FilmImage.objects.filter(film=film)

    return render_to_response('film_detail.html', {'film': film, 'images': images, 'form': form}, context_instance=RequestContext(request))

from forms import ContactForm
from django.core.mail import mail_managers

def contact(request, sent):
    if request.method == 'POST':
        form = ContactForm(request.POST)

        if form.is_valid():
            message = u'Uživatel vyplnil následující údaje:\n\n'

            for item in form.fields.keyOrder:
                if len(unicode(form.cleaned_data[item])) > 0:
                    message += form[item].label + u': ' + unicode(form.cleaned_data[item]) + u'\n'

            mail_managers('Nová zpráva z kontaktního formuláře', message)

            return HttpResponseRedirect('/kontakt/odeslano/')
    else:
        form = ContactForm()

    return render_to_response('contact.html', {'form': form, 'sent': sent}, context_instance=RequestContext(request))

from models import Profile
from forms import ProfileForm
from django.contrib.auth.decorators import login_required

@login_required
def profile(request, saved):
    try:
        profile = request.user.get_profile()
    except Profile.DoesNotExist:
        profile = Profile(user=request.user)

    if request.method == 'POST':
        form = ProfileForm(request.POST)

        if form.is_valid():
            request.user.first_name = form.cleaned_data['first_name']
            request.user.last_name = form.cleaned_data['last_name']
            request.user.email = form.cleaned_data['email']

            if len(form.cleaned_data['password1']) > 0:
                request.user.set_password(form.cleaned_data['password1'])

            request.user.save()

            profile.info = form.cleaned_data['info']
            profile.save()

            return HttpResponseRedirect('/accounts/profile/saved/')
    else:
        form = ProfileForm(initial={'first_name': request.user.first_name,
                                    'last_name': request.user.last_name,
                                    'email': request.user.email,
                                    'info': profile.info,
                                    })

    return render_to_response('profile.html', {'form': form, 'saved': saved}, context_instance=RequestContext(request))

@login_required
def members(request):
    return HttpResponseRedirect('/')
